/// Author				: Chbeir Elias & Jean-Francois Richard
/// Creation Date		: 04 June 2002
/// Modified by			: Parodi Alessandro
/// Modification Date	: 24 February 2004
///
/// Summary :
/// 
/// You can find the following functions in this file:
///
/// +   ChangeDestinationModule(newSrcValue)
/// +   ChangeDestinationPageModule(destination, newSrcValue)
/// +   DetectBrowser()
/// +   GetSelectedNodeFromUrl()
/// +   HighLightNode(selectedNode)
/// +   NextAndPreviousItems(nodeID, rank, originalBank)
/// +   SetMode(nodeID, mode)
/// +   ShowItems()
/// +   ShowNextAndPreviousEditions(NextAndPrevious, previousItemImg, ...)
/// +   ShowSubItems(module)

var Items               = new Array(); // Array that holds main Items; ones used as titles for sub items
var IDs                 = new Array(); // Array that holds the ids of the sub items (articles, news, ...)
var QID					= new Array(); // Array that holds the ids of the consulting's questions's parents
var QItemID				= new Array(); // Array that holds the ids of the consulting's questions

var e                   = 0;           // counter for Main Items (Editions, Magazines, ...)
var i                   = 0;           // counter for Sub Items (Articles, News, ...)
var t                   = 0;           // counter for Sub Themes
var counter             = 0;          
var q					= 0;		   // counter of the parents of the Consulting's questions
var qItems				= 0;		   // counter of the consultings questions
var rowsToShow          = 3;           // number of sub items to show under each main item
var selectedNode        = 0;           // selected node in page
var storedSelectedNode  = 0;           // holds previous selectedNode
var pageNodeToHighlight = 0;           // holds the id that can reference the current page; used to highlight
                                       // current page name in a module


/////////////////////////////////////////////////////////////////////////////////                      


/// <author>Chbeir Elias</author>
/// <summary>
/// Change the nodeid (src value) in current url
/// </summary>
/// <returns>current url with the updated nodeid value</returns>
function ChangeDestinationModule(newSrcValue)
{
	return ChangeDestinationPageModule("", newSrcValue)
}


//////////////////////////////////////////////////////////////////////////////////


/// <author>Chbeir Elias</author>
/// <summary>
/// Change the nodeid (sev value) in a given url
/// </summary>
/// <returns>given url with the updated nodeid value</returns>
function ChangeDestinationPageModule(destination, newSrcValue)
{


    var subparts;
    var partname;
    var nodeFromUrl = 0;
    var url         = "";
    
    if(destination == "")
		// get desired value from querystring
		url = document.location.toString();
	else
		url = destination;
		
	if(url.toString().indexOf("src") >= 0)
	{
		var urlLength = url.length;
		var srcStart  = url.indexOf("src") + 3; // +3 so to bypass the length of the word src
		var srcEnd    = "";
		var subUrl    = url.substring(srcStart).toString();
		var parts;
		
		// normal url
		if(subUrl.indexOf("=") == 0)
		{
			parts = subUrl.split("&");
			srcEnd = srcStart + parts[0].toString().length;
		}
		
		// url using isapi filter
		if(subUrl.indexOf("/") == 0)
		{
			parts = subUrl.split("/");
			
			if(parts[0].toString().length == 0)
				srcEnd = url.toString().length - 4; // at end, there should be ".htm" which is of length 4
			else
				srcEnd = srcStart + parts[0].toString().length;
		}
		
		srcStart += 1;  // +1 so to bypass the separator "=" or "/" after src
		
		return url.replace(url.substring(srcStart, srcEnd), newSrcValue);
	}
	
	return url;
}


/////////////////////////////////////////////////////////////////////////


/// <author>Richard Jean-Francois</author>
/// <summary>
/// Get the browser type at the client
/// </summary>
/// <returns>detected browser</returns>
function DetectBrowser()
{
	var Brw;
	
	if(document.all)
	{
		Brw = "MSIE";
	}
	if(document.layers)
	{
		Brw = "NS";
	}
	if(document.getElementById)
	{
		Brw = "NS6";
	}
	return Brw;
}

///////////////////////////////////////////////////////////////////////////


/// <author>Chbeir Elias</author>
/// <summary>
/// Get the selected node from the url by searching for the 'src' value in a url
/// </summary>
/// <returns>selected node</returns>
function GetSelectedNodeFromUrl()
{
	var subparts;
	var partname;
	var nodeFromUrl = 0;
	
	// get desired value from querystring
	var querystring = document.location.search;
	var queryparts  = querystring.split("&");
	
	for(var i = 0; i < queryparts.length; i++)
	{
		subparts = queryparts[i].split("=");
		partname = subparts[0].toString();
		
		if(partname.toLowerCase() == "src")
			nodeFromUrl = subparts[1];
	}
	
	// if isapi filter used (ex. "/map/show/111/src/11.htm")
	if(querystring == "")
	{
		var url = document.location;
		
		if(url.toString().indexOf("src") >=0)
		{
			queryparts = url.toString().split("src/");
			var src = queryparts[1];
			
			if(src.toString().indexOf("/") >= 0)
			{
				queryparts = src.toString().split("/");
				nodeFromUrl = queryparts[0];
			}
			else
			{
				queryparts = src.toString().split(".");
				nodeFromUrl = queryparts[0];
			}
		}
	}
	
	return nodeFromUrl;
}

/////////////////////////////////////////////////////////////////

/// <author>Jacquet Guillaume</author>
/// <summary>
/// Hide all items recorded whose name is in the QItemID array from the page
/// </summary>
function HideQItems()
{
	var module = "";
	
	for(var id = 0; id < QItemID.length; id++)
	{
		
		document.all(QItemID[id]).style.display = "none";
	}
	
}

/////////////////////////////////////////////////////////////////

/// <author>Chbeir Elias</author>
/// <summary>
/// Highlights the cell for the selected node
/// </summary>
function HighlightNode(selectedNode)
{
	var nodeToHighlight = GetSelectedNodeFromUrl();
	
	if (nodeToHighlight == 0)
		nodeToHighlight = selectedNode;
		
	selectedNode = nodeToHighlight;
	
	SetMode("ID" + selectedNode, "on"); selectedNode = 0;
	
}


/////////////////////////////////////////////////////////////////

/// <author>Chbeir Elias</author>
/// <summary>
/// NextAndPreviousItems acts like an object that whil hold a nodeid and its rank,
/// along with the original rank of current nodeid in a certain module
/// </summary>
function NextAndPreviousItems(nodeID, rank, originalRank)
{
	this.NodeID       = nodeID;
	this.Rank         = rank;
	this.OriginalRank = originalRank;
}


/////////////////////////////////////////////////////////////////


/// <author>Richard Jean-Francois</author>
/// <co-author>Chbeir Elias</co-author>
/// <summary>
/// Change Class Name of a certain item given its nodeid and the mode (on, off)
/// </summary>
function SetMode(nodeID, mode)
{
	var x;
	
	if((nodeID == 0)||(nodeID == "ID0"))
	{
		var ident = "";
		if(nodeID.toString().indexOf('ID') >=0)
			ident = "ID";
			
		nodeID = ident + GetSelectedNodeFromUrl();
	}
	
	if(mode.toLowerCase() == "on")
		if(storedSelectedNode == nodeID)
			return;
			
	storedSelectedNode = nodeID;
	
	var cName;
	var cItem;
	var browser = DetectBrowser();
	var cArrowImg;
	var flechaBlanca = "/site_images/MThem3b/flecha_blanca";
	
	//Detect browser
	switch (browser)
	{
		case "MSIE" :
			cItem = document.all(nodeID);
			cArrowImg = document.all(nodeID + "_Img");
			break;
		case "NS" :
			cItem = document.layers[nodeID];
			cArrowImg = document.layers[nodeID + "_Img"];
			break;
		case "NS6" :
			cItem = document.getElementById(nodeID);
			cArrowImg = document.getElementById(nodeID + "_Img");
			break;
	}
	
	if(cItem == null)
		return;
		
	// Get current class name
	cName = cItem.className;
	
	// Switch to new mode
	switch(mode.toLowerCase())
	{
		case 'on' :
			if(cName.indexOf('_on') == -1)
			{
				cItem.className = cName + '_on';
				if(cArrowImg != null)
					cArrowImg.src = flechaBlanca + "2.gif";
			}
			
			break;
		case 'off' :
			var cPos = cName.indexOf('_on');
			if(cPos != -1)
				cItem.className = cName.substring(0,cPos);
			break;
	}
}


/////////////////////////////////////////////////////////////////


/// <author>Chbeir Elias</author>
/// <summary>
/// Show only a certain number of rows (sub items) in required module(s)
/// hide the others items in the module(s)
/// </summary>
function ShowItems()
{
	var module = "";
	var noOfRows = 0;
	
	// form every module, show a certain number of items
	for(var item = 0; item < Items.length; item++)
	{
		module = Items[item];
		noOfRows = 0;
		
		// loop only within elements having the module in their id;
		// as an example : if "MThemList" is a module, the the id must be as "MThemList_123456"
		for(var id = 0; id < IDs.length; id++)
		{
			if (IDs[id].toString().indexOf(module) >= 0)
			{
				noOfRows++;
				if (noOfRows <= rowsToShow) // show elements until max number defined in var rowsToShow
					document.all(IDs[id]).style.display = "block";
				else
					document.all(IDs[id]).style.display = "none";
			}
		}
		
		if (noOfRows <= rowsToShow)
			document.all(module + "_show").style.display = "none";
	}
}


/////////////////////////////////////////////////////////////////


/// <author>Chbeir Elias</author>
/// <summary>
/// Shows the next and previous images and names with hyperlinks to
/// the next and previous editions
/// </summary>
function ShowNextAndPreviousEditions(NextAndPrevious, 
									 previousItemName, 
									 nextItemName,
									 activeClass,
									 highLightClass,
									 notActiveClass)
{
	var foundPrevious = false;
	var foundNext = false;
	var addSeparatorBar = false;
	var previousHref = "";
	var nextHref = "";
	
	if (NextAndPrevious.length != 0)
	{
		var originalRank = NextAndPrevious[0].OriginalRank;
		
		if (NextAndPrevious.length == 1)
		{
			if (NextAndPrevious[0].Rank < NextAndPrevious[0].OriginalRank)
			{
				previousHref = NextAndPrevious[0].NodeID;
				foundPrevious = true;
			}
			if (NextAndPrevious[0].Rank > NextAndPrevious[0].OriginalRank)
			{
				nextHref = NextAndPrevious[0].NodeID;
				foundNext = true;
			}
		}
		if (NextAndPrevious.length == 2)
		{
			previousHref = NextAndPrevious[0].NodeID;
			nextHref = NextAndPrevious[1].NodeID;
			foundPrevious = true;
			addSeparatorBar= true;
			foundNext = true;
		}
	}
	
	var previousItem = "";
	var nextItem = "";
	
	if (foundPrevious)
	{
		if (previousItemName != "")
			previousItem += "<div style='width:140px;' class='" + activeClass + "' onmouseover=\"this.className='" + highLightClass + "'\" onmouseout=\"this.className='" + activeClass + "'\" onclick=\"document.location='" + previousHref + "'\"><a class='menu_arial' href=\"" + previousHref + "\">" + previousItemName + "</a> </div></td>";
	}
	else
	{
		if (previousItemName != "")
			previousItem += "<div style='width:140px;' class='" + notActiveClass + "'>" + previousItemName + "</div>";
	}
	
	
	if (foundNext)
	{
		if (nextItemName != "")
			nextItem += "<td><div style='float:right;'><div style='width:140px;' class='" + activeClass + "' onclick='document.location=\"" + nextHref + "\"' onmouseover=\"this.className='" + highLightClass + "'\" onmouseout=\"this.className='" + activeClass + "'\"><a class='menu_arial' href=\"" + nextHref + "\">" + nextItemName + "</a></div></td>";
	}
	else
	{
		if (nextItemName != "")
			nextItem += "<td><div style='width:140px; float:right;' class='" + notActiveClass + "'>" + nextItemName + "</div></td>";
	}
	
	document.write(previousItem + nextItem);
}


//////////////////////////////////////////////////////////////

/// <author>Jacquet Guillaume</author>
/// <summary>
/// Show all items whose name contains the "title" string
/// </summary>

function ShowQItems(title)
{
	if(QID.length == 1)
	{
		document.all(QID[0]).style.display = "none";
	}
	else
	{
		// List all modules. If one of them is opened, close it. Else, verify if it's the searched one. If it is it, open it
		for(var item = 0; item < QItemID.length; item++)
		{
			if(document.all(QItemID[item]).style.display == "block")
			{
				document.all(QItemID[item]).style.display = "none";
			}
			else
			{
			// loop only within elements having the module in theis id;
			// as an example : if "MThemList" is a module, the the id must be as "MThemList_123456"
				if(QItemID[item].toString().indexOf(title) >= 0)
					document.all(QItemID[item]).style.display = "block";
			}
		}
	}
	
}

//////////////////////////////////////////////////////////////
/// <author>Chbeir Elias</author>
/// <summary>
/// Show all of the sub items within a module,
/// hiding items in all other modules exceeding rowsToShow
/// </summary>
function ShowSubItems(module)
{
	var verTodosItem;
	var itemModule;

	// start with showing items (not exceeding rowsToShow) in all modules
	ShowItems();
	
	// for every module, except current one, reset the hyperlink id to show
	for (var item = 0; item < Items.length; item++)
	{
		itemModule = Items[item];	
		
		if (itemModule.toString().toLowerCase() != module.toString().toLowerCase())
		{
			verTodosItem = document.all(itemModule + "_hide");
			
			if (verTodosItem != null)
			{
				itemModule = itemModule.toString().toLowerCase();
				if (verTodosItem.toString().toLowerCase().indexOf(itemModule) >= 0)
					document.all(itemModule + "_hide").id = itemModule + "_show";
			}
		}
	}

	// get hyperlink object of current module to see if we need to show or hide items in module
	verTodosItem = document.all(module + "_hide");
	
	// if hide was on then set hyperlink id to show and hide items exceeding rowsToShow
	if (verTodosItem != null)
	{
		document.all(module + "_hide").id = module + "_show";
		
		var noOfRows = 0;
		
		for (var id = 0; id < IDs.length; id++)
		{
			if (IDs[id].toString().indexOf(module) >= 0)
			{
				noOfRows++;
				if (noOfRows <= rowsToShow) // show elements until max number defined in var rowsToShow
					document.all(IDs[id]).style.display = "block";	
				else
					document.all(IDs[id]).style.display = "none";	
			}
		}
	}
	
	// if show was on then set hyperlink id to hide and show all items
	if (verTodosItem == null)
	{
		document.all(module + "_show").id = module + "_hide";
		
		for (var item = 0; item < IDs.length; item++)
		{
			if (IDs[item].toString().indexOf(module) >= 0)
				document.all(IDs[item]).style.display = "block";
		}	
	}		
}


//////////////////////////////////////////////////////////////
/// <author>Parodi Alessandro</author>
/// <summary>
/// Shows and hides items of the clicked folder for Lettere Tipo,
/// </summary>

// images
var minus = '/site_images/minus.gif';
var plus = '/site_images/plus.gif';

//	0 = closed;
//	1 = opened;

function LTOpenItem(open)
{
	var subItems = new Array();
	subItems = document.getElementsByTagName('div');
	
	for(var i = 0; i < subItems.length; i++)
	{
		if(subItems[i].id.indexOf('subItem_') == 0)
		{
			if(subItems[i].id == open)
			{
				// this condition is in case of click on already open item
				if(subItems[i].style.display == '')
				{
					subItems[i].style.display = 'none';
					MM_swapImage('img_' + subItems[i].id.substring(8),'',plus,1);
				}
				else
				{
					subItems[i].style.display = '';
					MM_swapImage('img_' + subItems[i].id.substring(8),'',minus,1);
				}
			}
			else
			{
				subItems[i].style.display = 'none';
				MM_swapImage('img_' + subItems[i].id.substring(8),'',plus,1);
			}
		}
	}
}